Basic Augmented Reality Demo.
===============================

.. image:: https://github.com/SciKit-Surgery/scikit-surgerybard/raw/master/sksbard_logo.png
   :height: 128px
   :width: 128px
   :target: https://github.com/SciKit-Surgery/scikit-surgerybard
   :alt: Logo

.. image:: https://github.com/SciKit-Surgery/scikit-surgerybard/workflows/.github/workflows/ci.yml/badge.svg 
   :target: https://github.com/SciKit-Surgery/scikit-surgerybard/actions
   :alt: Travis CI test status

.. image:: https://coveralls.io/repos/github/SciKit-Surgery/scikit-surgerybard/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/SciKit-Surgery/scikit-surgerybard?branch=master
    :alt: Test coverage

.. image:: https://readthedocs.org/projects/scikit-surgerybard/badge/?version=latest
    :target: http://scikit-surgerybard.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://img.shields.io/badge/Video-BARD-blueviolet
   :target: https://youtu.be/frviS--x5y4
   :alt: SciKit-SurgeryBARD Demonstration on YouTube

.. image:: https://img.shields.io/badge/Cite-SciKit--Surgery-informational
   :target: https://doi.org/10.1007/s11548-020-02180-5
   :alt: The SciKit-Surgery paper

.. image:: https://img.shields.io/twitter/follow/scikit_surgery?style=social
   :target: https://twitter.com/scikit_surgery?ref_src=twsrc%5Etfw
   :alt: Follow scikit_surgery on twitter


Authors: Matt Clarkson, Mian Ahmad, Tom Dowrick, Stephen Thompson

Basic Augmented Reality Demo (BARD) is part of the `SciKit-Surgery`_ software project, developed at the `Wellcome EPSRC Centre for Interventional and Surgical Sciences`_, part of `University College London (UCL)`_.

The BARD is tested on Python 3.6.


Developing
----------

Contributing
^^^^^^^^^^^^

Please see the `contributing guidelines`_.


Useful links
^^^^^^^^^^^^

* `Source code repository`_
* `Documentation`_


Licensing and copyright
-----------------------

Copyright 2019 University College London.
Basic Augmented Reality Demo. is released under the BSD-3 license. Please see the `license file`_ for details.


Acknowledgements
----------------

Supported by `Wellcome`_ and `EPSRC`_.


.. _`Wellcome EPSRC Centre for Interventional and Surgical Sciences`: http://www.ucl.ac.uk/weiss
.. _`source code repository`: https://github.com/SciKit-Surgery/scikit-surgerybard
.. _`Documentation`: https://scikit-surgerybard.readthedocs.io
.. _`SciKit-Surgery`: https://github.com/SciKit-Surgery/scikit-surgery/
.. _`University College London (UCL)`: http://www.ucl.ac.uk/
.. _`Wellcome`: https://wellcome.ac.uk/
.. _`EPSRC`: https://www.epsrc.ac.uk/
.. _`contributing guidelines`: https://github.com/SciKit-Surgery/scikit-surgerybard/blob/master/CONTRIBUTING.rst
.. _`license file`: https://github.com/SciKit-Surgery/scikit-surgerybard/blob/master/LICENSE

